.. SPDX-FileCopyrightText: 2024 Anna <cyber@sysrq.in>
.. SPDX-License-Identifier: CC0-1.0

Release Notes
=============

0.1.0
-----

* **New:** :py:func:`repology_client.resolve_package` function providing
  `Project by package name`__ tool's functionality.
* **Gone:** Python 3.10 support.
* Fix default session not closing properly.

__ https://repology.org/tools/project-by

0.0.2
-----

* Fix fetching >200 projects.

0.0.1
-----

* First release
